function loadTileQuads(path)
	local image = sheet:new(path)
	local quads = {}
	for i=1, image.height/16 do
		for j=1, image.width/16 do
			local q = love.graphics.newQuad((j-1)*16+j, (i-1)*16+i, 16, 16, image.width, image.height)
			table.insert(quads, q)
		end
	end

	return image, quads
end 

tile = class("tile")

terrainSheet, quads = loadTileQuads("terrainSheet")

waterSheet = sheet:new("waterSheet")

local waterGrid = anim8.newGrid(16,16, terrainSheet.width, terrainSheet.height, 0, 0, 1)

local waterAnimation = anim8.newAnimation(waterGrid("1-16", 5), 0.05) 
local waterAnimation2 = anim8.newAnimation(waterGrid("1-16", 6), 0.05) 

function updateWater(dt)
	waterAnimation:update(dt)
	waterAnimation2:update(dt)
end 

function tile:initialize(x, y, image)
	self.x = x
	self.y = y
	self.width = 16
	self.height = 16
	self.image = quads[image]
	self.id = image 
	self.animated = false 
	self.visible = true

	if image == 0 then 
		self.image = quads[1]
		self.visible = false
		self.animation = waterAnimation
	end

	if self.id == 201 then 
		self.animated = true 
		self.animation = waterAnimation
	elseif self.id == 251 then 
		self.animated = true
		self.animation = waterAnimation2
	end 
end

function tile:update(dt)
	if self.id == 201 then 
		self.animated = true 
		self.animation = waterAnimation
	elseif self.id == 251 then 
		self.animated = true
		self.animation = waterAnimation2
	end 
end

function tile:draw()
	if self.id > 0 then 
		if self.animated then 
			self.animation:draw(terrainSheet.image, self.x, self.y)
		else
			love.graphics.draw(terrainSheet.image, self.image, self.x, self.y)
		end 
	end
end 