--Remember that properties always are stings!! 

world = class("world")

function world:initialize(path)
	file = require("assets/maps/"..path)

	self.tileLayers = {}

	self.objectLayers = {}

	for i,v in pairs(file["layers"]) do
		if v.type == "tilelayer" then
			table.insert(self.tileLayers, initializeTileLayer(v))
		elseif v.type == "objectgroup" then
			table.insert(self.objectLayers, objectLayer:new(v))
		end
		
		local worldProgress = round(i/#file["layers"]*100,0)
		loadingScreen("World "..worldProgress.."%")
	end 
end

function world:draw()
	for i,v in pairs(self.tileLayers) do
		love.graphics.draw(v[1])
	end 

	for i,v in pairs(self.objectLayers) do
		love.graphics.draw(v.batch)
	end 
end	

function world:update(dt)
	renderDistanceWidth = round(w/cam.scale / 16 /2, 0) + 1
	renderDistanceHeight = round(h/cam.scale / 16 /2, 0) + 1

	for i, v in pairs(self.tileLayers) do
		if v[4] then 
			v[1]:clear()

			for j=round(player.y/16, 0) - renderDistanceHeight, round(player.y/16, 0) + renderDistanceHeight do
				for l= round(player.x/16, 0) - renderDistanceWidth, round(player.x/16, 0) + renderDistanceWidth do

					if v[3][j][l] ~= nil then 
						local tile = v[3][j][l]

						if tile.animated then 
							if tile.visible then 
								v[1]:add(tile.animation:getFrameInfo(tile.x,tile.y,0,1,1,0,0,0,0))
							end
						else
							if tile.visible then 
								v[1]:add(tile.image, tile.x, tile.y)
							end
						end
					end
				end
			end
		end 
	end
end

function initializeTileLayer(layer)
	if layer.properties["animated"] ~= nil  then 
		local batch = love.graphics.newSpriteBatch(terrainSheet.image, layer.width*layer.height)
		local canvas = love.graphics.newCanvas()
	
		local contents = {}

			for i=1,layer.height do
				local rows = {}
				for j=1, layer.width do 
					--J = x, i = y
					local image = layer.data[(i*layer.height +(j-1)-layer.width)+1]

					local tile = tile:new(j*16+1, i*16+1, image)

					batch:add(tile.image, tile.x, tile.y)
					table.insert(rows, tile)
				
				end
				table.insert(contents, rows)
			end
		if layer.properties["animated"] == "true" then 
			return {batch, layer, contents, true}
		elseif layer.properties["animated"] == "false" then
			return {batch, layer, contents, false}
		end
	end
end

objectLayer = class("objectLayer")

function objectLayer:initialize(layer)
	self.sheet, self.quads = loadTileQuads(layer.properties["sheet"])
	self.batch = love.graphics.newSpriteBatch(self.sheet.image)

	self.objects = {}

	for i, v in pairs(layer.objects) do
		local object = {
			x = v.x,
			y = v.y,
			width = v.width,
			height = v.height,
			image = self.quads[tonumber(v.properties["tile"])],
		}

		self.batch:add(object.image, object.x, object.y)
	end 

end
